"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var Promise = require('bluebird');
var Actions_1 = require('../../src/redux-retro//Actions');
describe('Actions', function () {
    var mockStore;
    beforeEach(function () {
        mockStore = {
            dispatch: jasmine.createSpy('dispatch')
        };
    });
    describe('Calling action methods', function () {
        describe('When an action method returns a payload that is not undefined or a promise', function () {
            var actionPayload = 'action payload';
            var PlainActions = (function (_super) {
                __extends(PlainActions, _super);
                function PlainActions() {
                    _super.apply(this, arguments);
                }
                PlainActions.prototype.someAction = function () {
                    return actionPayload;
                };
                return PlainActions;
            }(Actions_1.Actions));
            beforeEach(function () {
                var testActions = new PlainActions(mockStore);
                testActions.someAction();
            });
            it('should dispatch the action through the store', function () {
                expect(mockStore.dispatch.calls.count()).toBe(1);
            });
            it('should dispatch with an action type string that is an uppercase version of the method name', function () {
                expect(mockStore.dispatch.calls.first().args[0].type).toBe('SOME_ACTION');
            });
            it('should dispatch with a payload that is what the method returned', function () {
                expect(mockStore.dispatch.calls.first().args[0].payload).toBe(actionPayload);
            });
        });
        describe('When an action returns a promise', function () {
            var PromiseActions = (function (_super) {
                __extends(PromiseActions, _super);
                function PromiseActions() {
                    _super.apply(this, arguments);
                }
                PromiseActions.prototype.actionWithPromise = function () {
                    return Promise.resolve();
                };
                return PromiseActions;
            }(Actions_1.Actions));
            beforeEach(function () {
                var promiseActions = new PromiseActions(mockStore);
                promiseActions.actionWithPromise();
            });
            it('should not dispatch an action through the store', function () {
                expect(mockStore.dispatch).not.toHaveBeenCalled();
            });
        });
        describe('When an action returns nothing (undefined)', function () {
            var ActionsReturningNothing = (function (_super) {
                __extends(ActionsReturningNothing, _super);
                function ActionsReturningNothing() {
                    _super.apply(this, arguments);
                }
                ActionsReturningNothing.prototype.returnNothing = function () {
                    //Call some other actions or whatever
                };
                return ActionsReturningNothing;
            }(Actions_1.Actions));
            beforeEach(function () {
                var actionsReturningNothing = new ActionsReturningNothing(mockStore);
                actionsReturningNothing.returnNothing();
            });
            it('should not dispatch an action through the store', function () {
                expect(mockStore.dispatch).not.toHaveBeenCalled();
            });
        });
    });
    describe('Manually dispatching an action', function () {
        var actionType = 'MANUAL';
        var payload = 'payload';
        var ManualDispatch = (function (_super) {
            __extends(ManualDispatch, _super);
            function ManualDispatch() {
                _super.apply(this, arguments);
            }
            ManualDispatch.prototype.manualDispatch = function () {
                this.dispatch({
                    type: actionType,
                    payload: payload
                });
            };
            return ManualDispatch;
        }(Actions_1.Actions));
        beforeEach(function () {
            var manualDispatch = new ManualDispatch(mockStore);
            manualDispatch.manualDispatch();
        });
        it('should dispatch the action through the store', function () {
            expect(mockStore.dispatch.calls.count()).toBe(1);
            expect(mockStore.dispatch.calls.first().args[0].type).toBe(actionType);
            expect(mockStore.dispatch.calls.first().args[0].payload).toBe(payload);
        });
    });
});

//# sourceMappingURL=Actions.specs.js.map
